@@ -674,6 +674,7 @@ void Titraqform::setupTable(void)
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), SLOT(updSizes(int, int, int)));
     connect(m_pMaintable, SIGNAL(textEdited(int, int)), SLOT(dataChanged(int, int)));
+    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), SLOT(dataChanged(int, int)));
 }
 
 //
@@ -932,12 +933,12 @@ void Titraqform::setupEditlay(void)
     this->updSizes(TITRAQ_IDXALLCTRLS, -1, -1);
 
     // Validate data just as it is being entered
-    connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), SLOT(validateData(void)));
-    connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), SLOT(validateData(void)));
-    connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), SLOT(validateData(void)));
-    connect(m_pAmount, SIGNAL(valueChanged(const QTime &)), SLOT(validateData(void)));
-    connect(m_pTasks, SIGNAL(textChanged(const QString &)), SLOT(validateData(void)));
-    connect(m_pRemark, SIGNAL(textChanged(const QString &)), SLOT(validateData(void)));
+    connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), SLOT(validateRow(void)));
+    connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), SLOT(validateRow(void)));
+    connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), SLOT(validateRow(void)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QTime &)), SLOT(validateRow(void)));
+    connect(m_pTasks, SIGNAL(textChanged(const QString &)), SLOT(validateRow(void)));
+    connect(m_pRemark, SIGNAL(textChanged(const QString &)), SLOT(validateRow(void)));
 
     // Signals sent between table cells and corresponding edit control widgets
     connect(m_pLineedit, SIGNAL(textChanged(const QString &)), SLOT(updateLine(const QString &)));
@@ -1083,7 +1084,7 @@ void Titraqform::loadInit(void)
                 try {
                     this->setFilename(qApp->argv()[nIter]); // Store inital filename
                     Initial.setName(*this->getFilename());  // Initial file to load
-                    if (Initial.exists(*getFilename())) {
+                    if (Initial.exists(*getFilename()) && validateData(Initial)) {
                         this->loadData(Initial);            // Pass to helper method
                         enableIface(true);                  // Turn on the lights
                         m_pStatbar->message(trUtf8("Loaded document ") + *this->getFilename());
