@@ -216,6 +216,8 @@
 #define TITRAQ_INCOMPATDATA     "Error: incompatible data format."
 #define TITRAQ_INVALIDDATA      "Error: invalid data format."
 #define TITRAQ_SAVECANCELLED    "Warning: save operation failed, because the user cancelled."
+#define TITRAQ_READPFILFAIL     "Could not open personal data file for reading."
+#define TITRAQ_READAFILFAIL     "Could not open account file at %1 for reading."
 
 // Indexes of table columns
 #define TITRAQ_IDXALLCTRLS     -1
