@@ -228,8 +228,8 @@ protected slots:
     void onClick(int, int, int, const QPoint &); // Table was clicked
     void inplaceEdit(int, int, int, const QPoint &); // Enter in place edit mode
     void updEdit(int, int nCol = 0);    // Update edit controls
-    void validateData(void);            // Validate current row of matrix data
-    void validateData(int, int);        // Validate specified row of matrix data
+    void validateRow(void);             // Validate current row of matrix
+    void validateRow(int, int);         // Validate specified row of matrix
     void updSizes(int, int, int);       // Update edit sizes
     void calcCrc(void);                 // Calculate CRC of current row
     void calcCrc(int, int);             // Calculate CRC of specified row
@@ -318,6 +318,8 @@ private:
     void loadData(QTextStream &);       // Load personal data from stream
     void saveData(QFile &);             // Save accounting data to file
     void saveData(QTextStream &);       // Save accounting data to stream
+    const bool validateData(QFile &) const;   // Validate personal data in file
+    const bool validateData(QString &) const; // Validate personal data from string
 };
 
 #endif // AS_GUI_MWIN_H
