@@ -1,9 +1,9 @@
 //
 //  OSSP asgui - Accounting system graphical user interface
-//  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
-//  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-//  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
-//  Copyright (c) 2002-2003 Cable & Wireless Telecommunications Services GmbH
+//  Copyright (c) 2002-2004 The OSSP Project (http://www.ossp.org/)
+//  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
+//  Copyright (c) 2002-2004 Michael Schloh von Bennewitz <michael@schloh.com>
+//  Copyright (c) 2002-2004 Cable & Wireless Telecommunications Services GmbH
 //
 //  This file is part of OSSP asgui, an accounting system graphical user
 //  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
@@ -741,10 +741,10 @@ void Reportpanel::textChange(void)
     this->setCaption(trUtf8("AS local report", "Local report using weekly or monthly data."));
 
     // Top level push buttons associated with accept and save slots
-    m_pSavebutt->setText(trUtf8("Save", "Comment for Savebutton"));
+    m_pSavebutt->setText(trUtf8("Save As...", "Comment for Savebutton"));
     QToolTip::add(m_pSavebutt, trUtf8("Saves the report text", "Comment for tooltip Savebutton"));
     QWhatsThis::add(m_pSavebutt, trUtf8("The save button saves the report text to a file", "Comment for whatsThis Savebutton"));
-    m_pPrintbutt->setText(trUtf8("Print", "Comment for Printbutton"));
+    m_pPrintbutt->setText(trUtf8("Print...", "Comment for Printbutton"));
     QToolTip::add(m_pPrintbutt, trUtf8("Print the report text", "Comment for tooltip Printbutton"));
     QWhatsThis::add(m_pPrintbutt, trUtf8("The print button prints the report text to a file", "Comment for whatsThis Printbutton"));
     m_pDismissbutt->setText(trUtf8("Dismiss", "Comment for Dismissbutton"));
