@@ -133,7 +133,7 @@ void Titraqform::pasteEntry(void)
 
         // Do basic data validation to warn against missing fields
         for (int nIter = 0; nIter < nRows; nIter++)
-            this->validateData(m_pMaintable->currentRow() + nIter, 0);
+            this->validateRow(m_pMaintable->currentRow() + nIter, 0);
 
         m_pStatbar->message(QString::number(nRows) + trUtf8(" rows pasted"), 4000);
         updEdit(m_pMaintable->currentRow()); // Reflect in the update controls
@@ -168,7 +168,7 @@ void Titraqform::addEntry(int nRows)
         m_pMaintable->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.topRow(), m_pMaintable->currentColumn());
 
-        // According to Trolltech, insertRows() ''clears the selection(s).
+        // According to Trolltech, insertRows() "clears the selection(s)".
         // They are pretty wrong about that, so unfortunately we'll have to
         // take care of the dirty work ourselves with a clearSelection().
         m_pMaintable->clearSelection(false);
@@ -198,7 +198,7 @@ void Titraqform::addEntry(int nRows)
         m_pMaintable->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.bottomRow() + 1, m_pMaintable->currentColumn());
 
-        // According to Trolltech, insertRows() ''clears the selection(s).
+        // According to Trolltech, insertRows() "clears the selection(s)".
         // They are pretty wrong about that, so unfortunately we'll have to
         // take care of the dirty work ourselves with a clearSelection().
         m_pMaintable->clearSelection(false);
@@ -332,7 +332,7 @@ void Titraqform::refreshDisplay(void)
     // Sweep through matrix validating linewise
     // data and updating line numbers for all rows
     while (nIter < nRows) {
-        this->validateData(nIter, 0);
+        this->validateRow(nIter, 0);
         m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
         nIter++;
     }
@@ -430,19 +430,21 @@ void Titraqform::openDoc(void)
 
         // We might have a filename to work on, so do something with it
         if (!Filestring.isEmpty()) {
-            setFilename(Filestring);            // Set the new file name
-            m_pMaintable->setNumRows(0);        // Clear out old data
-            m_pMaintable->setDirty(false);      // Reset dirty flag
-            QFile Filetemp(Filestring);         // File to load
+            QFile Filetemp(Filestring);             // File to load
             try {
-                loadData(Filetemp);             // Pass to helper method
-                this->setCaption(Filestring);   // Caption in the titlebar
-                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-                this->enableIface(true);        // Turn on the lights
+                if (Filetemp.exists() && validateData(Filetemp)) { // Be extra sure
+                    setFilename(Filestring);        // Set the new file name
+                    m_pMaintable->setNumRows(0);    // Clear out old data
+                    m_pMaintable->setDirty(false);  // Reset dirty flag
+                    loadData(Filetemp);             // Pass to helper method
+                    this->setCaption(Filestring);   // Caption in the titlebar
+                    m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                    this->enableIface(true);        // Turn on the lights
+                    this->setOpen(true);            // Indicate doc is open
+                }
             }
             catch (Genexcept& Genex) { // Crap, we failed
                 m_pStatbar->message(trUtf8("Loading failed"), 4000);
-                this->setOpen(false);
                 Genex.reportErr();
                 return;
             }
@@ -680,10 +682,15 @@ void Titraqform::selAll(void)
 //
 void Titraqform::inplaceEdit(int nRow, int nCol, int nButton, const QPoint &Mousepos)
 {
+    // Table read only attribute must be reset here, so that editing can take
+    // place. Otherwise calls to editCell are ignored (for obvious reasons).
     m_pMaintable->setReadOnly(false);
+
+    // After editCell() is called, beginEdit() and endEdit() execute. The read
+    // only attribute is reset in endEdit() to return everything to normal.
     m_pMaintable->editCell(nRow, nCol);
+
     m_pMaintable->setEdition(nCol);
-    m_pMaintable->setReadOnly(true);
 }
 
 //
@@ -947,17 +954,17 @@ void Titraqform::updEdit(int nRow, int nCol)
 }
 
 //
-// Validate current row of matrix data
+// Validate current row of the matrix
 //
-void Titraqform::validateData(void)
+void Titraqform::validateRow(void)
 {
-    this->validateData(-1, -1);
+    this->validateRow(-1, -1);
 }
 
 //
-// Validate specified row of matrix data
+// Validate specified row of the matrix
 //
-void Titraqform::validateData(int nRow, int nCol)
+void Titraqform::validateRow(int nRow, int nCol)
 {
     int nRealrow = -1;
 
